@@ -1,6 +1,7 @@
 from cyberfusion.CoreApiClient import models
 from typing import Optional
 
+from cyberfusion.CoreApiClient._helpers import construct_includes_query_parameter
 from cyberfusion.CoreApiClient.http import DtoResponse
 from cyberfusion.CoreApiClient.interfaces import Resource
 
@@ -43,6 +44,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -52,9 +54,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(local_response, models.ClusterResource)
@@ -63,9 +64,13 @@ class Clusters(Resource):
         self,
         *,
         id_: int,
+        includes: list[str] | None = None,
     ) -> DtoResponse[models.ClusterResource]:
         local_response = self.api_connector.send_or_fail(
-            "GET", f"/api/v1/clusters/{id_}", data=None, query_parameters={}
+            "GET",
+            f"/api/v1/clusters/{id_}",
+            data=None,
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(local_response, models.ClusterResource)
@@ -205,18 +210,20 @@ class Clusters(Resource):
     def list_unix_users_home_directory_usages(
         self,
         *,
-        cluster_id: int,
+        id_: int,
         timestamp: str,
         time_unit: Optional[models.UNIXUsersHomeDirectoryUsageResource] = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.UNIXUsersHomeDirectoryUsageResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
-            f"/api/v1/clusters/unix-users-home-directories/usages/{cluster_id}",
+            f"/api/v1/clusters/{id_}/usages/unix-users-home-directory",
             data=None,
             query_parameters={
                 "timestamp": timestamp,
                 "time_unit": time_unit,
-            },
+            }
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -280,15 +287,13 @@ class Clusters(Resource):
         )
 
     def read_borg_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterBorgPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/borg",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -296,15 +301,13 @@ class Clusters(Resource):
         )
 
     def read_elasticsearch_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterElasticsearchPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/elasticsearch",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -312,15 +315,13 @@ class Clusters(Resource):
         )
 
     def read_firewall_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterFirewallPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/firewall",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -328,15 +329,13 @@ class Clusters(Resource):
         )
 
     def read_grafana_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterGrafanaPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/grafana",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -344,15 +343,13 @@ class Clusters(Resource):
         )
 
     def read_kernelcare_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterKernelcarePropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/kernelcare",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -360,15 +357,13 @@ class Clusters(Resource):
         )
 
     def read_load_balancing_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterLoadBalancingPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/load-balancing",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -376,15 +371,13 @@ class Clusters(Resource):
         )
 
     def read_mariadb_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterMariadbPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/mariadb",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -392,15 +385,13 @@ class Clusters(Resource):
         )
 
     def read_meilisearch_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterMeilisearchPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/meilisearch",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -408,15 +399,13 @@ class Clusters(Resource):
         )
 
     def read_metabase_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterMetabasePropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/metabase",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -424,15 +413,13 @@ class Clusters(Resource):
         )
 
     def read_new_relic_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterNewRelicPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/new-relic",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -440,15 +427,13 @@ class Clusters(Resource):
         )
 
     def read_nodejs_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterNodejsPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/nodejs",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -456,15 +441,13 @@ class Clusters(Resource):
         )
 
     def read_os_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterOsPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/os",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -472,15 +455,13 @@ class Clusters(Resource):
         )
 
     def read_php_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterPhpPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/php",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -488,15 +469,13 @@ class Clusters(Resource):
         )
 
     def read_postgresql_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterPostgresqlPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/postgresql",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -504,15 +483,13 @@ class Clusters(Resource):
         )
 
     def read_rabbitmq_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterRabbitmqPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/rabbitmq",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -520,15 +497,13 @@ class Clusters(Resource):
         )
 
     def read_redis_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterRedisPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/redis",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -536,15 +511,13 @@ class Clusters(Resource):
         )
 
     def read_singlestore_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterSinglestorePropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/singlestore",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -552,15 +525,13 @@ class Clusters(Resource):
         )
 
     def read_unix_users_properties(
-        self,
-        *,
-        id_: int,
+        self, *, id_: int, includes: list[str] | None = None
     ) -> DtoResponse[models.ClusterUnixUsersPropertiesResource]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             f"/api/v1/clusters/{id_}/properties/unix-users",
             data=None,
-            query_parameters={},
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -845,6 +816,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersBorgPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterBorgPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -854,9 +826,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -869,6 +840,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersRedisPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterRedisPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -878,9 +850,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -894,6 +865,7 @@ class Clusters(Resource):
         per_page: int = 0,
         include_filters: models.ClustersElasticsearchPropertiesSearchRequest
         | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterElasticsearchPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -903,9 +875,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -918,6 +889,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersFirewallPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterFirewallPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -927,9 +899,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -942,6 +913,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersGrafanaPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterGrafanaPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -951,9 +923,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -966,6 +937,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersKernelcarePropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterKernelcarePropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -975,9 +947,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -991,6 +962,7 @@ class Clusters(Resource):
         per_page: int = 0,
         include_filters: models.ClustersLoadBalancingPropertiesSearchRequest
         | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterLoadBalancingPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1000,9 +972,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1015,6 +986,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersMariadbPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterMariadbPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1024,9 +996,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1040,6 +1011,7 @@ class Clusters(Resource):
         per_page: int = 0,
         include_filters: models.ClustersMeilisearchPropertiesSearchRequest
         | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterMeilisearchPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1049,9 +1021,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1064,6 +1035,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersMetabasePropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterMetabasePropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1073,9 +1045,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1088,6 +1059,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersNewRelicPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterNewRelicPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1097,9 +1069,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1112,6 +1083,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersNodejsPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterNodejsPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1121,9 +1093,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1136,6 +1107,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersOsPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterOsPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1145,9 +1117,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1160,6 +1131,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersPhpPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterPhpPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1169,9 +1141,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1184,6 +1155,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersPostgresqlPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterPostgresqlPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1193,9 +1165,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1208,6 +1179,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersRabbitmqPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterRabbitmqPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1217,9 +1189,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1233,6 +1204,7 @@ class Clusters(Resource):
         per_page: int = 0,
         include_filters: models.ClustersSinglestorePropertiesSearchRequest
         | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterSinglestorePropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1242,9 +1214,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
@@ -1257,6 +1228,7 @@ class Clusters(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.ClustersUnixUsersPropertiesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.ClusterUnixUsersPropertiesResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -1266,9 +1238,8 @@ class Clusters(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(
